@@ -23,6 +23,10 @@
         <source>Thanks to</source>
         <translation>Danke an</translation>
     </message>
+    <message>
+        <source>Copyright</source>
+        <translation>Copyright</translation>
+    </message>
 </context>
 <context>
     <name>Albums</name>
@@ -71,6 +75,18 @@
         <source>Playlist</source>
         <translation>Abspielliste</translation>
     </message>
+    <message>
+        <source>Play</source>
+        <translation>Abspielen</translation>
+    </message>
+    <message>
+        <source>Remove from playlist</source>
+        <translation>Aus Liste entfernen</translation>
+    </message>
+    <message>
+        <source>Clear playlist</source>
+        <translation>Liste löschen</translation>
+    </message>
 </context>
 <context>
     <name>AuthenticationDialog</name>
@@ -79,16 +95,16 @@
         <translation>Authentifizierung</translation>
     </message>
     <message>
-        <source>Host %1 requires authentication</source>
-        <translation>Rechner %1 benötigt authentifizierung</translation>
+        <source>XBMC on %1 requires authentication:</source>
+        <translation>XBMC auf %1 verlangt authentifizierung:</translation>
     </message>
     <message>
-        <source>Username</source>
-        <translation>Benutzername</translation>
+        <source>Username:</source>
+        <translation>Benutzername:</translation>
     </message>
     <message>
-        <source>Password</source>
-        <translation>Passwort</translation>
+        <source>Password:</source>
+        <translation>Passwort:</translation>
     </message>
 </context>
 <context>
@@ -116,22 +132,10 @@
 </context>
 <context>
     <name>ConnectDialog</name>
-    <message>
-        <source>Connect to Xbmc</source>
-        <translation>Verbinde zu XBMC</translation>
-    </message>
     <message>
         <source>Host:</source>
         <translation>Rechner:</translation>
     </message>
-    <message>
-        <source>Http Port:</source>
-        <translation>HTTP Port:</translation>
-    </message>
-    <message>
-        <source>Searching for XBMC hosts. Make sure that remote controlling capabilities in XBMC are enabled and announced using Zeroconf. If you don&apos;t use Zeroconf, add a host manually.</source>
-        <translation>Suche nach XBMC Rechnern. Stellen Sie sicher, dass Fernsteuerungsschnittstelle und Zeroconf-Veröffentlichung in XBMC aktiviert sind. Wenn Sie Zeroconf nicht verwenden, fügen Sie den Rechner manuell hinzu.</translation>
-    </message>
     <message>
         <source>MAC Address (optional):</source>
         <translation>MAC Adresse (optional):</translation>
@@ -148,6 +152,38 @@
         <source>Remove Host</source>
         <translation>Entfernen</translation>
     </message>
+    <message>
+        <source>HTTP Port:</source>
+        <translation>HTTP Port:</translation>
+    </message>
+    <message>
+        <source>Connect to XBMC</source>
+        <translation>Verbinde mit XBMC</translation>
+    </message>
+    <message>
+        <source>Searching for XBMC hosts.</source>
+        <translation>Suche XBMC.</translation>
+    </message>
+    <message>
+        <source>Please enable the following options in the Network settings of XBMC:</source>
+        <translation>Bitte aktivieren Sie die folgenden Funktionen in den XBMC-Netzwerkeinstellungen:</translation>
+    </message>
+    <message>
+        <source>If you don&apos;t use Zeroconf, add a host manually.</source>
+        <translation>Wenn Sie Zeroconf nicht benutzen, fügen Sie den Ihr XBMC manuell hinzu.</translation>
+    </message>
+    <message>
+        <source>Allow control of XBMC via HTTP</source>
+        <translation>Steuerung über Webinterface zulassen</translation>
+    </message>
+    <message>
+        <source>Allow programs on other systems to control XBMC</source>
+        <translation>Stuerung über entfernte Programme zulassen</translation>
+    </message>
+    <message>
+        <source>Announce these services to other systems via Zeroconf</source>
+        <translation>Zeroconf-Veröffentlichung</translation>
+    </message>
     <message>
         <source>Back</source>
         <translation>Zurück</translation>
@@ -175,10 +211,6 @@
         <source>HTTP Port:</source>
         <translation>HTTP Port:</translation>
     </message>
-    <message>
-        <source>Searching for XBMC hosts. Make sure that remote controlling capabilities in XBMC are enabled and announced using Zeroconf. If you don&apos;t use Zeroconf, add a host manually.</source>
-        <translation>Suche nach XBMC Rechnern. Stellen Sie sicher, dass Fernsteuerungsschnittstelle und Zeroconf-Veröffentlichung in XBMC aktiviert sind. Wenn Sie Zeroconf nicht verwenden, fügen Sie den Rechner manuell hinzu.</translation>
-    </message>
     <message>
         <source>Remove Host</source>
         <translation>Entfernen</translation>
@@ -195,6 +227,30 @@
         <source>Back</source>
         <translation>Zurück</translation>
     </message>
+    <message>
+        <source>Searching for XBMC hosts.</source>
+        <translation>Suche XBMC.</translation>
+    </message>
+    <message>
+        <source>Please enable the following options in the Network settings of XBMC:</source>
+        <translation>Bitte aktivieren Sie die folgenden Funktionen in den XBMC-Netzwerkeinstellungen:</translation>
+    </message>
+    <message>
+        <source>If you don&apos;t use Zeroconf, add a host manually.</source>
+        <translation>Wenn Sie Zeroconf nicht benutzen, fügen Sie den Ihr XBMC manuell hinzu.</translation>
+    </message>
+    <message>
+        <source>Allow control of XBMC via HTTP</source>
+        <translation>Steuerung über Webinterface zulassen</translation>
+    </message>
+    <message>
+        <source>Allow programs on other systems to control XBMC</source>
+        <translation>Stuerung über entfernte Programme zulassen</translation>
+    </message>
+    <message>
+        <source>Announce these services to other systems via Zeroconf</source>
+        <translation>Zeroconf-Veröffentlichung</translation>
+    </message>
 </context>
 <context>
     <name>Episodes</name>
@@ -203,6 +259,29 @@
         <translation>Episoden</translation>
     </message>
 </context>
+<context>
+    <name>HomeMenu</name>
+    <message>
+        <source>Music</source>
+        <translation>Musik</translation>
+    </message>
+    <message>
+        <source>Videos</source>
+        <translation>Videos</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Bilder</translation>
+    </message>
+    <message>
+        <source>Files</source>
+        <translation>Dateien</translation>
+    </message>
+    <message>
+        <source>Library</source>
+        <translation>Bibliothek</translation>
+    </message>
+</context>
 <context>
     <name>ItemDetails</name>
     <message>
@@ -362,6 +441,17 @@
         <source>About</source>
         <translation>Über</translation>
     </message>
+    <message>
+        <source>Incoming call</source>
+        <translation>Eingehender Anruf</translation>
+    </message>
+</context>
+<context>
+    <name>MeeGoHelper</name>
+    <message>
+        <source>Incoming call</source>
+        <translation>Eingehender Anruf</translation>
+    </message>
 </context>
 <context>
     <name>Movies</name>
@@ -377,6 +467,17 @@
         <translation>Musikvideos</translation>
     </message>
 </context>
+<context>
+    <name>NfcHandler</name>
+    <message>
+        <source>NFC tag is not compatible with Xbmcremote. In order to use it with Xbmcremote you need to write connection information to it.</source>
+        <translation>NFC Tag ist nicht mit Xbmcremote kompatibel. Um dieses Tag mit Xbmcremote zu verwenden, müsses Sie es vorher beschreiben.</translation>
+    </message>
+    <message>
+        <source>NFC tag is outdated. In order to use it with Xbmcremote you need to update it by rewriting connection information to it.</source>
+        <translation>NFC Tag ist veraltet. Um dieses Tag weiterhin mit Xbmcremote zu verwenden, müsses Sie es erneut beschreiben.</translation>
+    </message>
+</context>
 <context>
     <name>NoConnectionPage</name>
     <message>
@@ -446,6 +547,10 @@
         <source>Pause video during calls</source>
         <translation>Pausiere Video währen Telefongesprächen</translation>
     </message>
+    <message>
+        <source>Pause music during calls</source>
+        <translation>Pausiere Musik währen Telefongesprächen</translation>
+    </message>
 </context>
 <context>
     <name>SettingsSheet</name>
@@ -485,6 +590,10 @@
         <source>Pause video</source>
         <translation>Pausiere Videos</translation>
     </message>
+    <message>
+        <source>Pause music</source>
+        <translation>Pausiere Musik</translation>
+    </message>
 </context>
 <context>
     <name>Shares</name>
@@ -547,19 +656,6 @@
 </context>
 <context>
     <name>WriteNfcTagSheet</name>
-    <message>
-        <source>Tap a NFC tag to write XBMC connection information to it. You can then use the tag to connect to XBMC.</source>
-        <translation>NFC Tag berühren um Schreibvorgang zu starten. Nach dem Beschreiben können Sie den NFC Tag dazu verwenden sich schnell mit XBMC zu verbinden.</translation>
-    </message>
-    <message>
-        <source>Tag written successfully.
-You can now use this tag
-to connect to XBMC.</source>
-        <translation>Tag erfolgreich geschrieben. 
-Sie konnen dieses Tag nun 
-benutzen um sich mit XBMC 
-zu verbinden.</translation>
-    </message>
     <message>
         <source>Close</source>
         <translation>Schließen</translation>
@@ -568,6 +664,18 @@ zu verbinden.</translation>
         <source>Cancel</source>
         <translation>Abbrechen</translation>
     </message>
+    <message>
+        <source>Tap a NFC tag to write XBMC connection information to it. You can then use the tag to connect to this XBMC.</source>
+        <translation>Berühren Sie ein NFC Tag um Verbindungsinformationen darauf zu speichern. Danach können Sie es zum Verbinden benutzen.</translation>
+    </message>
+    <message>
+        <source>Write NFC Tag</source>
+        <translation>NFC Tag schreiben</translation>
+    </message>
+    <message>
+        <source>Tag written successfully.</source>
+        <translation>Tag erfolgreich beschrieben.</translation>
+    </message>
 </context>
 <context>
     <name>XbmcConnection::XbmcConnectionPrivate</name>
@@ -639,16 +747,20 @@ zu verbinden.</translation>
         <translation>Abbrechen</translation>
     </message>
     <message>
-        <source>donate</source>
-        <translation>spenden</translation>
+        <source>Copyright</source>
+        <translation>Copyright</translation>
     </message>
     <message>
-        <source>flattr</source>
-        <translation>flattr</translation>
+        <source>Close</source>
+        <translation>Schließen</translation>
     </message>
     <message>
-        <source>close</source>
-        <translation>schließen</translation>
+        <source>Donate</source>
+        <translation>Spenden</translation>
+    </message>
+    <message>
+        <source>Flattr</source>
+        <translation>Flattr</translation>
     </message>
 </context>
 </TS>
