@@ -19,7 +19,7 @@ Settings::Settings(QObject *parent) :
 bool Settings::themeInverted() const
 {
     QSettings settings("xbmcremote");
-    return settings.value("InvertTheme", false).toBool();
+    return settings.value("InvertTheme", true).toBool();
 }
 
 void Settings::setThemeInverted(bool inverted)
@@ -42,31 +42,6 @@ void Settings::setUseThumbnails(bool useThumbnails)
     emit useThumbnailsChanged();
 }
 
-void Settings::setVolumeUpCommand(const QString &volumeUpCommand)
-{
-    QSettings settings("xbmcremote");
-    settings.setValue("VolumeUpCommand", volumeUpCommand);
-    emit volumeUpCommandChanged();
-}
-
-QString Settings::volumeUpCommand() const
-{
-    QSettings settings("xbmcremote");
-    return settings.value("VolumeUpCommand", QString()).toString();
-}
-
-void Settings::setVolumeDownCommand(const QString &volumeDownCommand)
-{
-    QSettings settings("xbmcremote");
-    settings.setValue("VolumeDownCommand", volumeDownCommand);
-    emit volumeDownCommandChanged();
-}
-
-QString Settings::volumeDownCommand() const
-{
-    QSettings settings("xbmcremote");
-    return settings.value("VolumeDownCommand", QString()).toString();
-}
 
 void Settings::setVolumeOnCall(int volume)
 {
@@ -81,6 +56,19 @@ int Settings::volumeOnCall() const
     return settings.value("VolumeOnCall", 10).toInt();
 }
 
+void Settings::setShowCallNotifications(bool show)
+{
+    QSettings settings("xbmcremote");
+    settings.setValue("ShowCallNotifications", show);
+    emit showCallNotificationsChanged();
+}
+
+bool Settings::showCallNotifications()
+{
+    QSettings settings("xbmcremote");
+    return settings.value("ShowCallNotifications", true).toBool();
+}
+
 bool Settings::changeVolumeOnCall() const
 {
     QSettings settings("xbmcremote");
@@ -94,17 +82,30 @@ void Settings::setChangeVolumeOnCall(bool changeVolume)
     emit changeVolumeOnCallChanged();
 }
 
-bool Settings::pauseOnCall() const
+bool Settings::pauseVideoOnCall() const
 {
     QSettings settings("xbmcremote");
-    return settings.value("PauseOnCall", true).toBool();
+    return settings.value("PauseVideoOnCall", true).toBool();
 }
 
-void Settings::setPauseOnCall(bool pause)
+void Settings::setPauseVideoOnCall(bool pause)
 {
     QSettings settings("xbmcremote");
-    settings.setValue("PauseOnCall", pause);
-    emit pauseOnCallChanged();
+    settings.setValue("PauseVideoOnCall", pause);
+    emit pauseVideoOnCallChanged();
+}
+
+bool Settings::pauseMusicOnCall() const
+{
+    QSettings settings("xbmcremote");
+    return settings.value("PauseMusicOnCall", false).toBool();
+}
+
+void Settings::setPauseMusicOnCall(bool pause)
+{
+    QSettings settings("xbmcremote");
+    settings.setValue("PauseMusicOnCall", pause);
+    emit pauseMusicOnCallChanged();
 }
 
 void Settings::addHost(const XbmcHost &host)
@@ -117,6 +118,8 @@ void Settings::addHost(const XbmcHost &host)
     settings.setValue("Password", host.password());
     settings.setValue("MAC", host.hwAddr());
     settings.setValue("Port", host.port());
+    settings.setValue("VolumeUpCommand", host.volumeUpCommand());
+    settings.setValue("VolumeDownCommand", host.volumeDownCommand());
 }
 
 void Settings::removeHost(const XbmcHost &host)
@@ -144,6 +147,8 @@ QList<XbmcHost> Settings::hostList() const
         host.setPort(settings.value("Port").toInt());
         host.setXbmcHttpSupported(true);
         host.setXbmcJsonrpcSupported(true);
+        host.setVolumeUpCommand(settings.value("VolumeUpCommand").toString());
+        host.setVolumeDownCommand(settings.value("VolumeDownCommand").toString());
         list.append(host);
         settings.endGroup();
     }
@@ -188,3 +193,29 @@ void Settings::setKeepDisplayLit(bool keepLit)
     settings.setValue("KeepDisplayLit", keepLit);
     emit keepDisplayLitChanged();
 }
+
+bool Settings::musicShowsFiles() const
+{
+    QSettings settings("xbmcremote");
+    return settings.value("MusicShowsFiles", false).toBool();
+}
+
+void Settings::setMusicShowsFiles(bool showFiles)
+{
+    QSettings settings("xbmcremote");
+    settings.setValue("MusicShowsFiles", showFiles);
+    emit musicShowsFilesChanged();
+}
+
+bool Settings::videoShowsFiles() const
+{
+    QSettings settings("xbmcremote");
+    return settings.value("VideoShowsFiles", false).toBool();
+}
+
+void Settings::setVideoShowsFiles(bool showFiles)
+{
+    QSettings settings("xbmcremote");
+    settings.setValue("VideoShowsFiles", showFiles);
+    emit videoShowsFilesChanged();
+}
