@@ -55,6 +55,11 @@ int sendCommand(const QString &command, const QVariant &params)
    return instance()->sendCommand(command, params);
 }
 
+void sendLegacyCommand(const QString &command)
+{
+   return instance()->sendLegacyCommand(command);
+}
+
 Notifier *notifier()
 {
     return instance()->notifier();
@@ -106,19 +111,35 @@ XbmcConnectionPrivate::XbmcConnectionPrivate(QObject *parent) :
 
     m_network = new QNetworkAccessManager();
     QObject::connect(m_network, SIGNAL(authenticationRequired(QNetworkReply*,QAuthenticator*)), SLOT(authenticationRequired(QNetworkReply*,QAuthenticator*)));
+
+    m_reconnectTimer.setInterval(5000);
+    m_reconnectTimer.setSingleShot(true);
+    QObject::connect(&m_reconnectTimer, SIGNAL(timeout()), SLOT(connect()));
 }
 
 void XbmcConnectionPrivate::connect(XbmcHost *host)
 {
-    m_socket->disconnectFromHost();
+    qDebug() << "connecting";
+    // Stop the reconnect timer in case someone else triggers the connect
+    m_reconnectTimer.stop();
 
-    m_host = host;
+    if(m_socket->state() == QAbstractSocket::ConnectedState) {
+        m_socket->disconnectFromHost();
+    }
 
-    xDebug(XDAREA_CONNECTION) << "connecting to" << host->hostname() << host->address() << host->username() << host->password();
+    if(m_socket->state() == QAbstractSocket::ConnectingState) {
+        m_socket->abort();
+    }
+
+    if(host != 0) {
+        m_host = host;
+    }
+
+    xDebug(XDAREA_CONNECTION) << "connecting to" << m_host->hostname() << m_host->address() << m_host->username() << m_host->password();
     // We connect to telnet on port 9090 for the announcements
-    m_socket->connectToHost(host->address(), 9090);
+    m_socket->connectToHost(m_host->address(), 9090);
 
-    m_connectionError = tr("Connecting to %1...").arg(host->hostname());
+    m_connectionError = tr("Connecting to %1...").arg(m_host->hostname());
     emit m_notifier->connectionChanged();
 }
 
@@ -151,9 +172,14 @@ void XbmcConnectionPrivate::slotDisconnected()
 void XbmcConnectionPrivate::socketError()
 {
     QString errorString = m_socket->errorString();
-    xDebug(XDAREA_CONNECTION) << "connection error:" << errorString;
-    m_connectionError = tr("Connection failed: %1").arg(errorString);
-    emit m_notifier->connectionChanged();
+    xDebug(XDAREA_CONNECTION) << "socket error:" << errorString;
+
+    if(m_socket->state() != QAbstractSocket::ConnectedState) {
+        m_connectionError = tr("Connection failed: %1").arg(errorString);
+        emit m_notifier->connectionChanged();
+        // silently try to reconnect if the connection failed
+        m_reconnectTimer.start();
+    }
 }
 
 void XbmcConnectionPrivate::sendNextCommand2() {
@@ -197,13 +223,14 @@ void XbmcConnectionPrivate::replyReceived()
 {
     QNetworkReply *reply = static_cast<QNetworkReply*>(sender());
     QString commands = reply->readAll();
+    reply->deleteLater();
+
     if(reply->error() != QNetworkReply::NoError) {
         m_socket->disconnectFromHost();
         m_connectionError = tr("Connection failed: %1").arg(reply->errorString());
         emit m_notifier->connectionChanged();
     }
 
-    qDebug() << "received reply:" << commands;
     xDebug(XDAREA_CONNECTION) << "received reply:" << commands;
 
     QStringList commandsList = commands.split("}{");
@@ -244,12 +271,14 @@ void XbmcConnectionPrivate::replyReceived()
                 m_connected = false;
                 m_connectionError = tr("Xbmcremote is designed to work with XBMC Eden (v11.0). It seems you have connected to an older version of XMBC. Please upgrade XBMC in order to use Xbmcremote.");
             } else {
+                m_timeoutTimer.stop();
+                m_currentPendingCommand = Command();
                 sendNextCommand2();
                 m_connected = true;
                 m_connectionError.clear();
             }
             emit m_notifier->connectionChanged();
-            return;
+            continue;
         }
 
         if(rsp.value("params").toMap().value("sender").toString() == "xbmc") {
@@ -293,6 +322,15 @@ int XbmcConnectionPrivate::sendCommand(const QString &command, const QVariant &p
     return id;
 }
 
+void XbmcConnectionPrivate::sendLegacyCommand(const QString &command)
+{
+    QNetworkRequest request;
+    request.setUrl(QUrl("http://" + m_host->address() + ':' + QString::number(m_host->port()) + "/xbmcCmds/xbmcHttp?command=" + command));
+    qDebug() << "sending legacy command:" << request.url().toString();
+    QNetworkReply *reply = m_network->get(request);
+    QObject::connect(reply, SIGNAL(finished()), reply, SLOT(deleteLater()));
+}
+
 void XbmcConnectionPrivate::sendNextCommand()
 {
     if(m_currentPendingCommand.id() >= 0 || m_socket->state() != QAbstractSocket::ConnectedState) {
@@ -393,7 +431,7 @@ void XbmcConnectionPrivate::readData()
 
 void XbmcConnectionPrivate::clearPending()
 {
-    xDebug(XDAREA_CONNECTION) << "timeouttimer hit for comman" << m_commandId;
+    xDebug(XDAREA_CONNECTION) << "timeouttimer hit for comman" << m_commandId << m_currentPendingCommand.id() << m_currentPendingCommand.command();
     if(m_commandId == m_versionRequestId) {
         xDebug(XDAREA_CONNECTION) << "cannot ask for remote version... ";
         m_connectionError = tr("Connection to %1 timed out...").arg(m_host->hostname());
@@ -437,6 +475,7 @@ void XbmcConnectionPrivate::authenticationRequired(QNetworkReply *reply, QAuthen
 
 void XbmcConnectionPrivate::setAuthCredentials(const QString &username, const QString &password)
 {
+    qDebug() << "setting auth credentials";
     if(m_host) {
         m_host->setUsername(username);
         m_host->setPassword(password);
